Convert maximum to logical while treating infinite values as NA
Source:R/helper_functions.R
as_logical_max_with_infinite_as_na.RdComputes the maximum value and converts it to logical, treating infinite values as NA. Useful for aggregating boolean data.