Calculate minimum while treating infinite values as NA
Source:R/helper_functions.R
min_with_infinite_as_na.RdComputes the minimum value of a numeric vector, converting any infinite values to NA. Useful for robust statistical calculations.

R/helper_functions.R
min_with_infinite_as_na.RdComputes the minimum value of a numeric vector, converting any infinite values to NA. Useful for robust statistical calculations.