Checks if any TRUE values exist in the preceding window, excluding the current row. Useful for determining if an event occurred in a prior time period.
Details
For infinite/large windows (>= 99999), uses O(n) cumsum approach. For finite windows, uses O(n) data.table::frollsum. Both exclude the current row (week 0).
See also
[steps_to_first()] for counting steps until first event
Other survival_analysis:
steps_to_first()