Adds a logical column indicating whether each row falls within the specified ISO years. Typically used to restrict analysis to a calendar period.
See also
[skeleton_eligible_combine()] to combine multiple eligibility criteria
Other skeleton_eligibility:
skeleton_eligible_age_range(),
skeleton_eligible_combine(),
skeleton_eligible_no_events_in_window_excluding_wk0(),
skeleton_eligible_no_events_lifetime_before_and_after_baseline(),
skeleton_eligible_no_observation_in_window_excluding_wk0()