Check eligibility based on no events in prior window (excluding baseline week)
Source:R/skeleton_utils.R
skeleton_eligible_no_events_in_window_excluding_wk0.RdAdds a logical column indicating whether there were NO TRUE values in the specified event variable within the prior window, EXCLUDING the current (baseline) week.
Usage
skeleton_eligible_no_events_in_window_excluding_wk0(
dt,
event_var,
window = 52,
col_name = NULL
)See also
[any_events_prior_to()], [skeleton_eligible_combine()]
Other skeleton_eligibility:
skeleton_eligible_age_range(),
skeleton_eligible_combine(),
skeleton_eligible_isoyears(),
skeleton_eligible_no_events_lifetime_before_and_after_baseline(),
skeleton_eligible_no_observation_in_window_excluding_wk0()